0.9.9 API documentation: Experimental extensions

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Modules
Experimental extensions

Experimental features not specified by GLSL specification. More...

## Modules
| GLM_GTX_associated_min_max
| Include <glm/gtx/associated_min_max.hpp> to use the features of this extension.
| GLM_GTX_bit
| Include <glm/gtx/bit.hpp> to use the features of this extension.
| GLM_GTX_closest_point
| Include <glm/gtx/closest_point.hpp> to use the features of this extension.
| GLM_GTX_color_encoding
| Include <glm/gtx/color_encoding.hpp> to use the features of this extension.
| GLM_GTX_color_space
| Include <glm/gtx/color_space.hpp> to use the features of this extension.
| GLM_GTX_color_space_YCoCg
| Include <glm/gtx/color_space_YCoCg.hpp> to use the features of this extension.
| GLM_GTX_common
| Include <glm/gtx/common.hpp> to use the features of this extension.
| GLM_GTX_compatibility
| Include <glm/gtx/compatibility.hpp> to use the features of this extension.
| GLM_GTX_component_wise
| Include <glm/gtx/component_wise.hpp> to use the features of this extension.
| GLM_GTX_dual_quaternion
| Include <glm/gtx/dual_quaternion.hpp> to use the features of this extension.
| GLM_GTX_easing
| Include <glm/gtx/easing.hpp> to use the features of this extension.
| GLM_GTX_euler_angles
| Include <glm/gtx/euler_angles.hpp> to use the features of this extension.
| GLM_GTX_extend
| Include <glm/gtx/extend.hpp> to use the features of this extension.
| GLM_GTX_extented_min_max
| Include <glm/gtx/extented_min_max.hpp> to use the features of this extension.
| GLM_GTX_exterior_product
| Include <glm/gtx/exterior_product.hpp> to use the features of this extension.
| GLM_GTX_fast_exponential
| Include <glm/gtx/fast_exponential.hpp> to use the features of this extension.
| GLM_GTX_fast_square_root
| Include <glm/gtx/fast_square_root.hpp> to use the features of this extension.
| GLM_GTX_fast_trigonometry
| Include <glm/gtx/fast_trigonometry.hpp> to use the features of this extension.
| GLM_GTX_functions
| Include <glm/gtx/functions.hpp> to use the features of this extension.
| GLM_GTX_gradient_paint
| Include <glm/gtx/gradient_paint.hpp> to use the features of this extension.
| GLM_GTX_handed_coordinate_space
| Include <glm/gtx/handed_coordinate_system.hpp> to use the features of this extension.
| GLM_GTX_hash
| Include <glm/gtx/hash.hpp> to use the features of this extension.
| GLM_GTX_integer
| Include <glm/gtx/integer.hpp> to use the features of this extension.
| GLM_GTX_intersect
| Include <glm/gtx/intersect.hpp> to use the features of this extension.
| GLM_GTX_io
| Include <glm/gtx/io.hpp> to use the features of this extension.
| GLM_GTX_log_base
| Include <glm/gtx/log_base.hpp> to use the features of this extension.
| GLM_GTX_matrix_cross_product
| Include <glm/gtx/matrix_cross_product.hpp> to use the features of this extension.
| GLM_GTX_matrix_decompose
| Include <glm/gtx/matrix_decompose.hpp> to use the features of this extension.
| GLM_GTX_matrix_factorisation
| Include <glm/gtx/matrix_factorisation.hpp> to use the features of this extension.
| GLM_GTX_matrix_interpolation
| Include <glm/gtx/matrix_interpolation.hpp> to use the features of this extension.
| GLM_GTX_matrix_major_storage
| Include <glm/gtx/matrix_major_storage.hpp> to use the features of this extension.
| GLM_GTX_matrix_operation
| Include <glm/gtx/matrix_operation.hpp> to use the features of this extension.
| GLM_GTX_matrix_query
| Include <glm/gtx/matrix_query.hpp> to use the features of this extension.
| GLM_GTX_matrix_transform_2d
| Include <glm/gtx/matrix_transform_2d.hpp> to use the features of this extension.
| GLM_GTX_mixed_producte
| Include <glm/gtx/mixed_product.hpp> to use the features of this extension.
| GLM_GTX_norm
| Include <glm/gtx/norm.hpp> to use the features of this extension.
| GLM_GTX_normal
| Include <glm/gtx/normal.hpp> to use the features of this extension.
| GLM_GTX_normalize_dot
| Include <glm/gtx/normalized_dot.hpp> to use the features of this extension.
| GLM_GTX_number_precision
| Include <glm/gtx/number_precision.hpp> to use the features of this extension.
| GLM_GTX_optimum_pow
| Include <glm/gtx/optimum_pow.hpp> to use the features of this extension.
| GLM_GTX_orthonormalize
| Include <glm/gtx/orthonormalize.hpp> to use the features of this extension.
| GLM_GTX_perpendicular
| Include <glm/gtx/perpendicular.hpp> to use the features of this extension.
| GLM_GTX_polar_coordinates
| Include <glm/gtx/polar_coordinates.hpp> to use the features of this extension.
| GLM_GTX_projection
| Include <glm/gtx/projection.hpp> to use the features of this extension.
| GLM_GTX_quaternion
| Include <glm/gtx/quaternion.hpp> to use the features of this extension.
| GLM_GTX_range
| Include <glm/gtx/range.hpp> to use the features of this extension.
| GLM_GTX_raw_data
| Include <glm/gtx/raw_data.hpp> to use the features of this extension.
| GLM_GTX_rotate_normalized_axis
| Include <glm/gtx/rotate_normalized_axis.hpp> to use the features of this extension.
| GLM_GTX_rotate_vector
| Include <glm/gtx/rotate_vector.hpp> to use the features of this extension.
| GLM_GTX_scalar_relational
| Include <glm/gtx/scalar_relational.hpp> to use the features of this extension.
| GLM_GTX_spline
| Include <glm/gtx/spline.hpp> to use the features of this extension.
| GLM_GTX_std_based_type
| Include <glm/gtx/std_based_type.hpp> to use the features of this extension.
| GLM_GTX_string_cast
| Include <glm/gtx/string_cast.hpp> to use the features of this extension.
| GLM_GTX_texture
| Include <glm/gtx/texture.hpp> to use the features of this extension.
| GLM_GTX_transform
| Include <glm/gtx/transform.hpp> to use the features of this extension.
| GLM_GTX_transform2
| Include <glm/gtx/transform2.hpp> to use the features of this extension.
| GLM_GTX_type_aligned
| Include <glm/gtx/type_aligned.hpp> to use the features of this extension.
| GLM_GTX_type_trait
| Include <glm/gtx/type_trait.hpp> to use the features of this extension.
| GLM_GTX_vec_swizzle
| Include <glm/gtx/vec_swizzle.hpp> to use the features of this extension.
| GLM_GTX_vector_angle
| Include <glm/gtx/vector_angle.hpp> to use the features of this extension.
| GLM_GTX_vector_query
| Include <glm/gtx/vector_query.hpp> to use the features of this extension.
| GLM_GTX_wrap
| Include <glm/gtx/wrap.hpp> to use the features of this extension.

## Detailed Description

Experimental features not specified by GLSL specification.

Experimental extensions are useful functions and types, but the development of their API and functionality is not necessarily stable. They can change substantially between versions. Backwards compatibility is not much of an issue for them.

Even if it's highly unrecommended, it's possible to include all the extensions at once by including <glm/ext.hpp>. Otherwise, each extension needs to be included a specific file.